summaryrefslogtreecommitdiff
path: root/src/script/api/script_accounting.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_accounting.cpp')
-rw-r--r--src/script/api/script_accounting.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/script/api/script_accounting.cpp b/src/script/api/script_accounting.cpp
index 3255f8613..dfe05df3b 100644
--- a/src/script/api/script_accounting.cpp
+++ b/src/script/api/script_accounting.cpp
@@ -7,28 +7,28 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file script_accounting.cpp Implementation of AIAccounting. */
#include "../../stdafx.h"
#include "script_accounting.hpp"
-Money AIAccounting::GetCosts()
+Money ScriptAccounting::GetCosts()
{
return this->GetDoCommandCosts();
}
-void AIAccounting::ResetCosts()
+void ScriptAccounting::ResetCosts()
{
this->SetDoCommandCosts(0);
}
-AIAccounting::AIAccounting()
+ScriptAccounting::ScriptAccounting()
{
this->last_costs = this->GetDoCommandCosts();
this->SetDoCommandCosts(0);
}
-AIAccounting::~AIAccounting()
+ScriptAccounting::~ScriptAccounting()
{
this->SetDoCommandCosts(this->last_costs);
}
@@ -7,28 +7,28 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file script_accounting.cpp Implementation of AIAccounting. */
+/** @file script_accounting.cpp Implementation of ScriptAccounting. */
#include "../../stdafx.h"
#include "script_accounting.hpp"